@@ -5,20 +5,23 @@ eval 'require Digest::MD5';
 	URI HTML::Parser LWP);
 @useful = (qw(Tie::Cache Tie::Depth
         Storable Time::Timezone Sys::Syslog Net::Daemon
-        RPC::PlServer Clone
+        RPC::PlServer Clone HTML::Tagset
         DBI DBD::XBase DB_File File::Tools Mail::Tools
-	SQL::Statement Text::CSV_XS DBD::CSV FreezeThaw IniConf
-        Data::Dumper GD MLDBM Convert::BER Net::LDAP XML::Parser
-        Net::DNS Net::Whois Net::Country Tie::Cache 
-	Filter::Util::Call Template XML::Simple Date::Language
-        XML::Conf Config::IniFiles));
+	SQL::Statement Text::CSV_XS DBD::CSV FreezeThaw 
+        Data::Dumper GD MLDBM Convert::BER IO::Socket::SSL
+	Convert::ASN1 Net::LDAP XML::Parser
+        Net::DNS Net::Whois Net::Country 
+	Filter::Util::Call Text::Autoformat Template XML::Simple
+	Date::Language XML::Conf Config::IniFiles IniConf));
+
+%answers = ('Template', 'n');
 
 if ($ARGV[0] eq 'NOPREREQ') {
 	@modules = @useful;
 	shift @ARGV;
 } else {
 	@modules = (@prereq, @useful);
-        if ($] < 5.6) {
+        if ($] < 5.006) {
             print "Try: perl pre-install NOPREREQ\nif CPAN tries helplessly to download Perl 5.6.0 and install it\07\n";
             sleep 4;
         }
@@ -26,17 +29,24 @@ if ($ARGV[0] eq 'NOPREREQ') {
 
 unshift(@INC, $ARGV[0]) if (@ARGV);
 
+close(STDIN);
+
 &cls;
 &confcpan;
 &makeobjs;
 
 foreach $mod (@objs) {
         &cls;
+	pipe(STDIN, W);
+	$a = $answers{$mod};
+	$a =~ s/(\\.)/"$1"/ge;
+	print W $a;
 	eval { $mod->install; };
         if ($loop < @prereq) {
             $nm = $modules[$loop++];
             eval "require $nm;";
         }
+	close(W);
 }
 
 &cls;
